@@ -5,28 +5,30 @@ import time
 from assertpy import assert_that
 from typing import Dict, Tuple, TYPE_CHECKING
 
-
-
 from deepdriver import logger
 from deepdriver.sdk import util
 from deepdriver.sdk.interface import interface
 from deepdriver.sdk.interface.grpc_interface_pb2 import *
+
 if TYPE_CHECKING:
     from deepdriver.sdk.artifact import Artifact
 
 run: Run = None
 
+
 def set_run(run_: Run) -> None:
     global run
     run = run_
 
+
 def get_run() -> Run:
     global run
     return run
 
+
 class Run:
 
-    def __init__(self, team_name: str, exp_name: str, run_name: str, run_id: int=0, run_url: str="") -> None:
+    def __init__(self, team_name: str, exp_name: str, run_name: str, run_id: int = 0, run_url: str = "") -> None:
         assert_that(team_name).is_not_none()
         assert_that(exp_name).is_not_none()
         assert_that(run_name).is_not_none()
@@ -39,7 +41,7 @@ class Run:
         self.run_start_time = time.time()
 
         # 로그 스텝(Run.log로 기록 될 때마다 1씩 증가)
-        self.log_step = 0
+        self.log_step: int = 0
 
         self.lastData = {}
 
@@ -50,10 +52,9 @@ class Run:
         # item에 key값이 “timestamp” 이고 value가 현재시각 (time.time())인 item도 추가
         # item에 로그의 key value값의 쌍이 들어가도록 item을 추가ex) log({“loss” :0.03, “acc” :0.97}) -> key가 loss 이고 value가 0.03인 item과 key가 acc이고 value가 0.97인 item이 추가됨
 
-
         from deepdriver.sdk.data_types.image import Image
         from deepdriver.sdk.data_types.table import Table
-        from deepdriver.sdk.chart.chart import Chart
+        from deepdriver.sdk.chart.chart import Chart, TYPE_HISTOGRAM
 
         for key, value in data.items():
             # TODO: Image, Chart등 다른 데이터 형식도 추가해야함
@@ -62,26 +63,28 @@ class Run:
                 logger.debug(f"Table을 str(json)로 변환 변환 : {data[key]}")
                 value.upload_file(self, key)
             elif isinstance(value, Image):
-                data[key] = value.to_json(key)
+                data[key] = value.to_json(key, log_step=self.log_step)
                 logger.debug(f"Image를 str(json)로 변환 변환 : {data[key]}")
-                value.upload_file(self, key)
+                value.upload_file(self, key, log_step=self.log_step)
             elif isinstance(value, Chart):
-                data[key] = value.to_json(key, only_meta=True)
-                logger.debug(f"Chart를 str(json)로 변환 변환 : {data[key]}")
-                value.upload_file(self, key)
+                if value.chart_type == TYPE_HISTOGRAM:  # histogram 일 경우 log_step 전송
+                    data[key] = value.to_json(key, only_meta=True, log_step=self.log_step)
+                    logger.debug(f"Chart(Histogram)를 str(json)로 변환 변환 : {data[key]}")
+                    value.upload_file(self, key, log_step=self.log_step)
+                else:
+                    data[key] = value.to_json(key, only_meta=True)
+                    logger.debug(f"Chart를 str(json)로 변환 변환 : {data[key]}")
+                    value.upload_file(self, key)
             elif isinstance(value, list):
-                if all(isinstance(n, Image) for n in value):    #Image 객체 배열일 경우
-                        list_dict = []
-                        for index, n in enumerate(value):
-                            list_dict.append(n.to_dict(key_name=key, is_list=True, index=index))
-                            n.upload_file(self, key, is_list=True, index=index)
-                        data[key] = json.dumps(list_dict)
-
-
-                        logger.debug(f"Image 객체(배열)을 str(json)로 변환 변환 : {data[key]}")
-
-
+                if all(isinstance(n, Image) for n in value):  # Image 객체 배열일 경우
+                    list_dict = []
+                    for index, n in enumerate(value):
+                        n: Image = n
+                        list_dict.append(n.to_dict(key_name=key, is_list=True, index=index, log_step=self.log_step))
+                        n.upload_file(self, key, is_list=True, index=index, log_step=self.log_step)
+                    data[key] = json.dumps(list_dict)
 
+                    logger.debug(f"Image 객체(배열)을 str(json)로 변환 변환 : {data[key]}")
 
         data["timestamp"] = time.time()
 
@@ -108,7 +111,7 @@ class Run:
         assert_that(artifact).is_not_none()
         return artifact.upload()
 
-    def get_artifact(self, name: str, type: str, tag: str="", team_name: str="", exp_name: str="") -> Tuple[
+    def get_artifact(self, name: str, type: str, tag: str = "", team_name: str = "", exp_name: str = "") -> Tuple[
         int, ArtifactRecord]:
         assert_that(name).is_not_none()
         assert_that(type).is_not_none()
@@ -124,7 +127,7 @@ class Run:
         data = {
             "runId": self.run_id,
             "summary": {
-                "_runtime": time.time()-self.run_start_time,
+                "_runtime": time.time() - self.run_start_time,
                 "_step": self.log_step,
                 "_custom": _custom,
             },
@@ -132,9 +135,5 @@ class Run:
         resp = interface.finish(data)
         return resp["result"] == "success"
 
-
-    def alert(self, alert_msg:str):
+    def alert(self, alert_msg: str):
         return interface.send_alert(self.run_id, self.team_name, self.exp_name, alert_msg)
-
-
-
